
import {axios} from '@/utils/request'

export function yardPhotoList(parameter) {
    return axios({
      url: "/ctop/yard/photo/list",
      method: 'get',
      params: parameter
    })
}
export function yardListDelete(parameter) {
    return axios({
      url: "/ctop/yard/delete",
      method: 'delete',
      params: parameter
    })
}

export function yardVideoList(parameter) {
    return axios({
      url: "/ctop/yard/video/list",
      method: 'get',
      params: parameter
    })
}

export function yardPhotoDelete(parameter) {
    return axios({
      url: "/ctop/yard/photo/delete",
      method: 'delete',
      params: parameter
    })
}

export function yardVideoDelete(parameter) {
    return axios({
      url: "/ctop/yard/video/delete",
      method: 'delete',
      params: parameter
    })
}

export function yardPhotoAdd(parameter) {
    return axios({
      url: "/ctop/yard/photo/add",
      method: 'post',
      params: parameter
    })
}

export function yardVideoAdd(parameter) {
    return axios({
      url: "/ctop/yard/video/add",
      method: 'post',
      params: parameter
    })
}